@@ -138,6 +138,7 @@ class ConfigurationManager(types.ModuleType):
         # set a flag to indicate if config is dirty and the hub needs to reload
         # (something's changed but not taken yet into account)
         byscopes["_dirty"] = self.dirty
+        byscopes["allow_edits"] = self.allow_edits
         return byscopes
 
     def clear_cache(self):
@@ -617,3 +618,13 @@ def get_loop(max_workers=None):
     executor = concurrent.futures.ProcessPoolExecutor(max_workers=max_workers)
     loop.set_default_executor(executor)
     return loop
+
+
+# adjust some loggers...
+if os.environ.get("HUB_VERBOSE","0") != "1":
+    logging.getLogger("elasticsearch").setLevel(logging.ERROR)
+    logging.getLogger("urllib3").setLevel(logging.ERROR)
+    logging.getLogger("requests").setLevel(logging.ERROR)
+    logging.getLogger("botocore").setLevel(logging.ERROR)
+    logging.getLogger("boto").setLevel(logging.ERROR)
+    logging.getLogger("git").setLevel(logging.ERROR)
