@@ -76,7 +76,7 @@ class BaseDiffer(object):
         src_build = get_src_build()
         job_info = {
             'status': status,
-            'step_started_at': datetime.now(),
+            'step_started_at': datetime.now().astimezone(),
             'logfile': self.logfile,
         }
         diff_key = self.old.target_name
@@ -89,7 +89,7 @@ class BaseDiffer(object):
             job_info["time"] = timesofar(self.ti)
             t1 = round(time.time() - self.ti, 0)
             job_info["time_in_s"] = t1
-            diff_info["diff"][diff_key]["created_at"] = datetime.now()
+            diff_info["diff"][diff_key]["created_at"] = datetime.now().astimezone()
         if "diff" in extra:
             diff_info["diff"][diff_key].update(extra["diff"])
         if "job" in extra:
@@ -219,7 +219,7 @@ class BaseDiffer(object):
                     # when "new" is a target collection:
                     "mapping_file": None,
                     "info": {
-                        "generated_on": str(datetime.now()),
+                        "generated_on": str(datetime.now().astimezone()),
                         "exclude": exclude,
                         "steps": steps,
                         "mode": mode,
@@ -1097,6 +1097,8 @@ class DifferManager(BaseManager):
             def diffed(f):
                 try:
                     _ = f.result()
+                    # after creating a build diff, indicate
+                    # a release note should be auto generated
                     set_pending_to_release_note(new)
                 except Exception as e:
                     self.logger.error("Error during diff: %s" % e)
