@@ -3,11 +3,10 @@
 """
 import asyncio
 
-from elasticsearch import (ConnectionError, NotFoundError, RequestError,
-                           TransportError)
-from tornado.web import HTTPError
-
 from biothings.web.handlers.exceptions import BadRequest, EndRequest
+from elasticsearch import (ConnectionError, ConnectionTimeout, NotFoundError,
+                           RequestError, TransportError)
+from tornado.web import HTTPError
 
 
 class ESQueryBackend(object):
@@ -30,9 +29,14 @@ class ESQueryBackend(object):
 
     async def execute(self, query, options):
         '''
-        Execute the corresponding query.
+        Execute the corresponding query. Must return an awaitable.
         May override to add more. Handle uncaught exceptions.
-        Must return an awaitable.
+
+        Options:
+            Required: either an es-dsl query object or scroll_id
+            Optional:
+                fetch_all: also return a scroll_id for this query (default: false)
+                biothing_type: which type's corresponding indices to query (default in config.py)
         '''
         if options.scroll_id:
             try:
@@ -49,21 +53,21 @@ class ESQueryBackend(object):
                 return res
 
         if query:
-            biothing_type = options.pop('biothing_type', None) or self.default_type
+            biothing_type = options.get('biothing_type', None) or self.default_type
             query = query.index(self.indices.get(biothing_type, self.default_index))
 
-            if options.pop('fetch_all', False):
+            if options.get('fetch_all', False):
                 query = query.params(scroll=self.scroll_time)
                 query = query.extra(size=self.scroll_size)
             try:
                 res = await query.using(self.client).execute()
-            except ConnectionError:
+            except (ConnectionError, ConnectionTimeout):
                 raise HTTPError(503)
             except RequestError as exc:
                 raise BadRequest(_es_error=exc)
             except TransportError as exc:
                 if exc.error == 'search_phase_execution_exception':
-                    raise BadRequest(reason=exc.error)
+                    raise EndRequest(500, reason=exc.info)
                 elif exc.error == 'index_not_found_exception':
                     raise HTTPError(500, reason=exc.error)
                 elif exc.status_code == 'N/A':
